@@ -424,6 +424,40 @@ ostree_async_progress_set_uint64 (OstreeAsyncProgress       *self,
   ostree_async_progress_set_variant (self, key, g_variant_new_uint64 (value));
 }
 
+/**
+ * ostree_async_progress_copy_state:
+ * @self: An #OstreeAsyncProgress to copy from
+ * @dest: An #OstreeAsyncProgress to copy to
+ *
+ * Atomically copies all the state from @self to @dest, without invoking the
+ * callback.
+ * This is used for proxying progress objects across different #GMainContexts.
+ *
+ * Since: 2019.6
+ */
+void
+ostree_async_progress_copy_state (OstreeAsyncProgress *self,
+                                  OstreeAsyncProgress *dest)
+{
+  g_return_if_fail (OSTREE_IS_ASYNC_PROGRESS (self));
+  g_return_if_fail (OSTREE_IS_ASYNC_PROGRESS (dest));
+
+  g_mutex_lock (&self->lock);
+
+  if (self->dead)
+    goto out;
+
+  GLNX_HASH_TABLE_FOREACH_KV (self->values, void *, key, GVariant *, value)
+    {
+      if (value)
+        g_variant_ref (value);
+      g_hash_table_replace (dest->values, key, value);
+    }
+
+ out:
+  g_mutex_unlock (&self->lock);
+}
+
 /**
  * ostree_async_progress_new:
  *
@@ -465,7 +499,7 @@ ostree_async_progress_finish (OstreeAsyncProgress *self)
       if (self->idle_source)
         {
           g_source_destroy (self->idle_source);
-          self->idle_source = NULL;
+          g_clear_pointer (&self->idle_source, g_source_unref);
           emit_changed = TRUE;
         }
     }
