@@ -28,9 +28,7 @@
 #include "ostree.h"
 
 static char *opt_mode = "bare";
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
 static char *opt_collection_id = NULL;
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
 
 /* ATTENTION:
  * Please remember to update the bash-completion script (bash/ostree) and
@@ -38,11 +36,9 @@ static char *opt_collection_id = NULL;
  */
 
 static GOptionEntry options[] = {
-  { "mode", 0, 0, G_OPTION_ARG_STRING, &opt_mode, "Initialize repository in given mode (bare, archive)", NULL },
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
+  { "mode", 0, 0, G_OPTION_ARG_STRING, &opt_mode, "Initialize repository in given mode (bare, bare-user, bare-user-only, archive)", NULL },
   { "collection-id", 0, 0, G_OPTION_ARG_STRING, &opt_collection_id,
     "Globally unique ID for this repository as an collection of refs for redistribution to other repositories", "COLLECTION-ID" },
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
   { NULL }
 };
 
@@ -61,10 +57,8 @@ ostree_builtin_init (int argc, char **argv,OstreeCommandInvocation *invocation,
 
   if (!ostree_repo_mode_from_string (opt_mode, &mode, error))
     goto out;
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
   if (!ostree_repo_set_collection_id (repo, opt_collection_id, error))
     goto out;
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
 
   if (!ostree_repo_create (repo, mode, NULL, error))
     goto out;
