@@ -25,7 +25,8 @@ set -euo pipefail
 
 skip_without_user_xattrs
 
-setup_test_repository "bare-user"
+mode="bare-user"
+setup_test_repository "$mode"
 
 extra_basic_tests=6
 . $(dirname $0)/basic-test.sh
@@ -117,9 +118,10 @@ assert_file_has_content ls.txt "^-006.. ${newuid} ${newgid} .*/baz/cow"
 
 # But --devino-canonical should override that
 $OSTREE commit ${COMMIT_ARGS} --owner-uid ${newuid} --owner-gid ${newgid} \
-        -I -b test2-devino-test --tree=dir=test2-checkout
+        -I -b test2-devino-test --table-output --tree=dir=test2-checkout > out.txt
 $OSTREE ls test2-devino-test /baz/cow > ls.txt
 assert_file_has_content ls.txt "^-006.. ${myuid} ${mygid} .*/baz/cow"
+assert_file_has_content out.txt "Content Cache Hits: [1-9][0-9]*"
 
 $OSTREE refs --delete test2-{linkcheckout,devino}-test
 echo "ok commit with -I"
