@@ -21,6 +21,11 @@
 
 set -euo pipefail
 
+if ! ostree --version | grep -q -e '- libarchive'; then
+    echo "1..0 #SKIP no libarchive support compiled in"
+    exit 0
+fi
+
 . $(dirname $0)/libtest.sh
 
 setup_test_repository "archive"
